package RDF::iCalendar::Line;

use 5.008;
use base qw[RDF::vCard::Line];
use strict;

our $VERSION = '0.003';

1;

__END__

=head1 NAME

RDF::iCalendar::Line - represents a line within a vCard

=head1 DESCRIPTION

This is a trivial subclass of L<RDF::vCard::Line>.

=head1 SEE ALSO

L<RDF::iCalendar>, L<RDF::vCard::Line>.

=head1 AUTHOR

Toby Inkster E<lt>tobyink@cpan.orgE<gt>.

=head1 COPYRIGHT

Copyright 2011 Toby Inkster

This library is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

